#! /usr/bin/env python

from __future__ import print_function
from openturns import *
from math import sqrt, pi, exp, log

TESTPREAMBLE()
RandomGenerator.SetSeed(0)
ResourceMap.SetAsUnsignedInteger("RandomMixture-DefaultMaxSize", 4000000)
# Deactivate the simplification mechanism as we want to test the Poisson formula
# based algorithm here
ResourceMap.SetAsBool("RandomMixture-SimplifyAtoms", False)

try:
    # Create a collection of test-cases and the associated references
    numberOfTests = 3
    testCases = list()
    references = DistributionCollection(numberOfTests)
    testCases.append(DistributionCollection(2))
    testCases[0][0] = Uniform(-1.0, 3.0)
    testCases[0][1] = Uniform(-1.0, 3.0)
    references[0] = Triangular(-2.0, 2.0, 6.0)
    testCases.append(DistributionCollection(3))
    testCases[1][0] = Normal()
    testCases[1][1] = Normal(1.0, 2.0)
    testCases[1][2] = Normal(-2.0, 2.0)
    references[1] = Normal(-1.0, 3.0)
    testCases.append(DistributionCollection(3))
    testCases[2][0] = Exponential()
    testCases[2][1] = Exponential()
    testCases[2][2] = Exponential()
    references[2] = Gamma(3.0, 1.0, 0.0)
    print("testCases=", testCases)
    print("references=", references)
    for testIndex in range(len(testCases)):
        # Instanciate one distribution object
        distribution = RandomMixture(testCases[testIndex])
        distribution.setBlockMin(5)
        distribution.setBlockMax(20)
        distributionReference = references[testIndex]
        print("Distribution ", repr(distribution))
        print("Distribution ", distribution)

        # Is this distribution elliptical ?
        print("Elliptical = ", distribution.isElliptical())

        # Is this distribution continuous ?
        print("Continuous = ", distribution.isContinuous())

        # Test for realization of distribution
        oneRealization = distribution.getRealization()
        print("oneRealization=", oneRealization)

        # Test for sampling
        size = 10000
        oneSample = distribution.getSample(size)
        print("oneSample first=", oneSample[0], " last=", oneSample[size - 1])
        print("mean=", oneSample.computeMean())
        print("covariance=", oneSample.computeCovariance())

        # Define a point
        point = Point(distribution.getDimension(), 0.5)
        print("Point= ", point)

        # Show PDF and CDF of point
        eps = 1e-5
        DDF = distribution.computeDDF(point)[0]
        print("ddf      =%.5g" % DDF)
        print("ddf (ref)=", distributionReference.computeDDF(point))
        PDF = distribution.computePDF(point)
        print("pdf      =%.6f" % PDF)
        print("pdf  (FD)=%.6f" % ((distribution.computeCDF(point + Point(1, eps)) -
                                   distribution.computeCDF(point + Point(1, -eps))) / (2.0 * eps)))
        print("pdf (ref)=%.6f" % distributionReference.computePDF(point))
        CDF = distribution.computeCDF(point)
        print("cdf      =%.6f" % CDF)
        print("cdf (ref)=%.6f" % distributionReference.computeCDF(point))
        CF = distribution.computeCharacteristicFunction(point[0])
        print("characteristic function=%.6f + %.6fi" % (CF.real, CF.imag))
        LCF = distribution.computeLogCharacteristicFunction(point[0])
        print("log characteristic function=%.6f + %.6fi" %
              (LCF.real, LCF.imag))
        quantile = distribution.computeQuantile(0.95)
        print("quantile      =", quantile)
        print("quantile (ref)=", distributionReference.computeQuantile(0.95))
        print("cdf(quantile)=%.6f" % distribution.computeCDF(quantile))
        quantileComp = distribution.computeQuantile(0.95, True)
        print("quantile comp.=", quantileComp)
        print("cdfComp(quantileComp)=%.6f" %
              distribution.computeComplementaryCDF(quantileComp))
        # Get 95% survival function
        inverseSurvival = Point(
            distribution.computeInverseSurvivalFunction(0.95))
        print("InverseSurvival=", repr(inverseSurvival))
        print("Survival(inverseSurvival)=%.6f" %
              distribution.computeSurvivalFunction(inverseSurvival))
        # Entropy: too expansive for now...
        if False:
            print("entropy=%.6f" % distribution.computeEntropy())

        # Confidence regions: too expansive for now...
        if False:
            print("dimension=", distribution.getDimension(),
                  "test case=", testIndex)
            interval, threshold = distribution.computeMinimumVolumeIntervalWithMarginalProbability(
                0.95)
            print("Minimum volume interval=", interval)
            print("threshold=", Point(1, threshold))
            levelSet, beta = distribution.computeMinimumVolumeLevelSetWithThreshold(
                0.95)
            print("Minimum volume level set=", levelSet)
            print("beta=", Point(1, beta))
            interval, beta = distribution.computeBilateralConfidenceIntervalWithMarginalProbability(
                0.95)
            print("Bilateral confidence interval=", interval)
            print("beta=", Point(1, beta))
            interval, beta = distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(
                0.95, False)
            print("Unilateral confidence interval (lower tail)=", interval)
            print("beta=", Point(1, beta))
            interval, beta = distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(
                0.95, True)
            print("Unilateral confidence interval (upper tail)=", interval)
            print("beta=", Point(1, beta))

        mean = distribution.getMean()
        print("mean      =", mean)
        print("mean (ref)=", distributionReference.getMean())
        standardDeviation = distribution.getStandardDeviation()
        print("standard deviation      =", standardDeviation)
        print("standard deviation (ref)=",
              distributionReference.getStandardDeviation())
        skewness = distribution.getSkewness()
        print("skewness      =", skewness)
        print("skewness (ref)=", distributionReference.getSkewness())
        kurtosis = distribution.getKurtosis()
        print("kurtosis      =", kurtosis)
        print("kurtosis (ref)=", distributionReference.getKurtosis())
        covariance = distribution.getCovariance()
        print("covariance      =", covariance)
        print("covariance (ref)=", distributionReference.getCovariance())
        parameters = distribution.getParametersCollection()
        print("parameters=", parameters)
        print("Standard representative=",
              distribution.getStandardRepresentative())
        print("blockMin=", distribution.getBlockMin())
        print("blockMax=", distribution.getBlockMax())
        print("maxSize=", distribution.getMaxSize())
        print("alpha=", distribution.getAlpha())
        print("beta=", distribution.getBeta())
    # Tests of the simplification mechanism
    weights = Point(0)
    coll = DistributionCollection(0)
    coll.add(Dirac(0.5))
    weights.add(1.0)
    coll.add(Normal(1.0, 2.0))
    weights.add(2.0)
    coll.add(Normal(2.0, 1.0))
    weights.add(-3.0)
    coll.add(Uniform(-2.0, 2.0))
    weights.add(-1.0)
    coll.add(Uniform(2.0, 4.0))
    weights.add(2.0)
    coll.add(Exponential(2.0, -3.0))
    weights.add(1.5)
    rm = RandomMixture(coll, weights)
    coll.add(rm)
    weights.add(-2.5)
    coll.add(Gamma(3.0, 4.0, -2.0))
    weights.add(2.5)
    distribution = RandomMixture(coll, weights)
    print("distribution=", repr(distribution))
    print("distribution=", distribution)
    mu = distribution.getMean()[0]
    sigma = distribution.getStandardDeviation()[0]
    for i in range(10):
        x = mu + (-3.0 + 6.0 * i / 9.0) * sigma
        print("pdf( %.6f )=%.6f" % (x, distribution.computePDF(x)))

    # Tests of the projection mechanism
    collFactories = [UniformFactory(), NormalFactory(
    ), TriangularFactory(), ExponentialFactory(), GammaFactory()]
    #, TrapezoidalFactory()
    result, norms = distribution.project(collFactories)
    print("projections=", result)
    print("norms=", norms)
    # ------------------------------ Multivariate tests ------------------------------#
    # 2D RandomMixture
    collection = DistributionCollection(0)
    collection.add(Normal(0.0, 1.0))
    collection.add(Normal(0.0, 1.0))
    collection.add(Normal(0.0, 1.0))

    weightMatrix = Matrix(2, 3)
    weightMatrix[0, 0] = 1.0
    weightMatrix[0, 1] = -2.0
    weightMatrix[0, 2] = 1.0
    weightMatrix[1, 0] = 1.0
    weightMatrix[1, 1] = 1.0
    weightMatrix[1, 2] = -3.0

    # Build the RandomMixture
    distribution2D = RandomMixture(collection, weightMatrix)
    print("distribution = ", distribution2D)
    print("range = ", distribution2D.getRange())
    print("mean = ",  distribution2D.getMean())
    print("cov = ", distribution2D.getCovariance())
    print("sigma = ", distribution2D.getStandardDeviation())
    distribution2D.setBlockMin(3)
    distribution2D.setBlockMax(10)

    # Build a grid for validation
    xMin = distribution2D.getRange().getLowerBound()[0]
    xMax = distribution2D.getRange().getUpperBound()[0]
    yMin = distribution2D.getRange().getLowerBound()[1]
    yMax = distribution2D.getRange().getUpperBound()[1]
    # Number of points of discretization
    nx = 4
    ny = 4
    boxParameters = Point(2)
    boxParameters[0] = nx
    boxParameters[1] = ny
    boxGrid = Box(boxParameters)
    grid = boxGrid.generate()
    # scaling box grid
    scaleFactor = Point(2)
    scaleFactor[0] = 0.25 * (xMax - xMin)
    scaleFactor[1] = 0.25 * (yMax - yMin)
    grid *= scaleFactor
    # translating
    translateFactor = Point(2)
    translateFactor[0] = distribution2D.getMean()[0]
    translateFactor[1] = distribution2D.getMean()[1]
    grid += translateFactor
    # Compute PDF
    # parameters for theoritical PDF, obtained thanks to Maple
    factor = sqrt(2) / (20 * pi)
    for index in range(grid.getSize()):
        point = grid[index]
        PDF = distribution2D.computePDF(point)
        # Very small values are not very accurate on x86, skip them
        if (PDF < 1.e-12):
            continue
        print("pdf      = %.6g" % PDF)
        x, y = tuple(point)
        pdf_ref = factor * \
            exp(-3.0 / 50.0 * y * y - 2.0 / 25 * x * y - 11.0 / 100 * x * x)
        print("pdf (ref)= %.6g" % pdf_ref)

    # 2D test, but too much CPU consuming
    collUniforme = DistributionCollection(0)
    collUniforme.add(Uniform(0, 1))
    collUniforme.add(Uniform(0, 1))
    collUniforme.add(Uniform(0, 1))
    # Build the RandomMixture
    dist_2D = RandomMixture(collUniforme, weightMatrix)
    dist_2D.setBlockMin(3)
    dist_2D.setBlockMax(8)

    print("new distribution = ", dist_2D)
    print("range = ", dist_2D.getRange())
    print("mean = ",  dist_2D.getMean())
    print("cov = ", dist_2D.getCovariance())
    print("sigma = ", dist_2D.getStandardDeviation())

    # Discretization on grid mu, mu + \sigma
    newGrid = boxGrid.generate()
    # scaling box grid
    newGrid *= dist_2D.getStandardDeviation()
    # translating
    newGrid += dist_2D.getMean()
    # Compute PDF
    for index in range(newGrid.getSize()):
        point = newGrid[index]
        PDF = dist_2D.computePDF(point)
        print("pdf      = %.6g" % PDF)

    # 3D test
    ResourceMap.SetAsUnsignedInteger("RandomMixture-DefaultMaxSize", 8290688)
    mixture = Mixture([Normal(2, 1), Normal(-2, 1)])
    collection = [Normal(0.0, 1.0), mixture, Uniform(0, 1), Uniform(0, 1)]
    matrix = Matrix(
        [[1, -0.05, 1, -0.5], [0.5, 1, -0.05, 0.3], [-0.5, -0.1, 1.2, -0.8]])
    dist_3D = RandomMixture(collection, matrix)
    dist_3D.setBlockMin(3)
    dist_3D.setBlockMax(6)

    print("3D distribution = ", dist_3D)
    print("range = ", dist_3D.getRange())
    print("mean = ",  dist_3D.getMean())
    print("cov = ", dist_3D.getCovariance())
    print("sigma = ", dist_3D.getStandardDeviation())
    # Total number of points (is (2+2)**3)
    # Test is CPU consuming
    N = 2
    b = Box([N, N, N])
    # Grid ==> (mu, mu+sigma)
    grid3D = b.generate() * dist_3D.getStandardDeviation() + dist_3D.getMean()

    for i in range(grid3D.getSize() // 4):
        point = grid3D[4 * i]
        PDF = dist_3D.computePDF(point)
        print("pdf      = %.6g" % PDF)

    # For ticket 882
    mixture = RandomMixture([Dirac()])
    graph = mixture.drawPDF()
    graph = mixture.drawCDF()

    # Test computeQuantile for the specific case of an analytical 1D mixture
    case1 = 0.1 * ChiSquare()
    q = case1.computeQuantile(0.95)[0]
    print("case 1, q=%.6f" % q)
    q = case1.computeQuantile(0.95, True)[0]
    print("case 1, q comp=%.6f" % q)
    case2 = -0.1 * ChiSquare()
    q = case2.computeQuantile(0.95)[0]
    print("case 2, q=%.6f" % q)
    q = case2.computeQuantile(0.95, True)[0]
    print("case 2, q comp=%.6f" % q)
    # For ticket 953
    atom1 = TruncatedDistribution(Uniform(0.0, 1.0), 0.0, 1.0)
    atom2 = Uniform(0.0, 2.0)
    sum = atom1 + atom2
    print("sum=", sum)
    print("CDF=%.6g" % sum.computeCDF(2.0))
    print("quantile=", sum.computeQuantile(0.2))
    minS = 0.2
    maxS = 10.0
    muS = (log(minS) + log(maxS)) / 2.0
    sigma = (log(maxS) - muS) / 3.0
    atom1 = TruncatedDistribution(LogNormal(muS, sigma), minS, maxS)
    atom2 = Uniform(0.0, 2.0)
    sum = atom1 + atom2
    print("sum=", sum)
    print("CDF=%.6g" % sum.computeCDF(2.0))
    print("quantile=", sum.computeQuantile(0.2))
    # For ticket 1129
    dist = RandomMixture([Uniform()]*200)
    print("CDF(0)=%.5g" % dist.computeCDF([0]))
except:
    import sys
    print("t_RandomMixture_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot
import openturns.testing as ott

ot.Log.Show(ot.Log.ALL)

dim = 3
model = ot.SymbolicFunction(['x0', 'x1', 'x2'],
                            ['sin(x0)*cos(x1)*exp(x2)+x0*x1*x2', '(-1+x0*x0^2+x0^3)*(2+x1+2*x1^2+3*x1^5)*(15+2*x2+5*x2^7)'])
coll = [ot.Uniform()] * dim


# friedman
# dim = 5
# model = ot.SymbolicFunction(['x1', 'x2', 'x3', 'x4', 'x5'],
#['10*sin(pi_*x1*x2)+20*(x3-0.5)^2+10*x4+5*x5'])
# coll = [ot.Uniform(0., 1.)] * dim


# borehole
# dim = 8
# model = ot.SymbolicFunction(['rw', 'r', 'Tu', 'Hu', 'Tl', 'Hl', 'L', 'Kw'],
#['(2*pi_*Tu*(Hu-Hl))/(ln(r/rw)*(1+(2*L*Tu)/(ln(r/rw)*rw^2*Kw)+Tu/Tl))'])
# coll = [ot.Normal(0.1, 0.0161812),
# ot.LogNormal(7.71, 1.0056),
# ot.Uniform(63070.0, 115600.0),
# ot.Uniform(990.0, 1110.0),
# ot.Uniform(63.1, 116.0),
# ot.Uniform(700.0, 820.0),
# ot.Uniform(1120.0, 1680.0),
# ot.Uniform(9855.0, 12045.0)]

distribution = ot.ComposedDistribution(coll)
factoryCollection = [ot.OrthogonalUniVariateFunctionFamily(
    ot.OrthogonalUniVariatePolynomialFunctionFactory(ot.StandardDistributionPolynomialFactory(dist))) for dist in coll]


functionFactory = ot.OrthogonalProductFunctionFactory(factoryCollection)

size = 1000
X = distribution.getSample(size)
Y = model(X)


# ot.ResourceMap.Set('TensorApproximationAlgorithm-Method', 'RankM')

# n-d
nk = [10] * dim
maxRank = 5
algo = ot.TensorApproximationAlgorithm(
    X, Y, distribution, functionFactory, nk, maxRank)
algo.run()
result = algo.getResult()
# print('residuals=', result.getResiduals())
ott.assert_almost_equal(result.getResiduals(), [0.000466643, 0.0])

metamodel = result.getMetaModel()
x = distribution.getMean()
print('x=', ot.Point(x), 'f(x)=', model(x), 'f^(x)=', metamodel(x))
for i in range(model.getOutputDimension()):
    print('rank[', i, ']=', result.getTensor(i).getRank())



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    # pNormal
    xMin = 0.1
    xMax = 0.9
    nX = 10
    grid = [0.0]*nX
    for iX in range(nX):
        x = xMin + (xMax - xMin) * iX / (nX - 1)
        grid[iX] = x
        print("pNormal( %.12g" % x, ")=%.6g" % DistFunc.pNormal(
            x), ", complementary=%.6g" % DistFunc.pNormal(x, True))
    print("pNormal(", grid, "=", DistFunc.pNormal(grid))
    # qNormal
    qMin = 0.1
    qMax = 0.9
    nQ = 10
    grid = [0.0]*nQ
    for iQ in range(nQ):
        q = qMin + (qMax - qMin) * iQ / (nQ - 1)
        grid[iQ] = q
        print("qNormal( %.12g" % q, ")=%.6g" % DistFunc.qNormal(
            q), ", complementary=%.6g" % DistFunc.qNormal(q, True))
    print("qNormal(", grid, ")=", DistFunc.qNormal(grid))
    # rNormal
    nR = 10
    for iR in range(nR):
        print("rNormal()=%.6g" % DistFunc.rNormal())
except:
    import sys
    print("t_DistFunc_normal.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

try:
    hermite = HermiteFactory()
    print("hermite=", hermite)
    for i in range(10):
        print("hermite(", i, ")=", hermite.build(i))
    roots = hermite.getRoots(10)
    print("hermite(10) roots=", repr(roots))
    nodes, weights = hermite.getNodesAndWeights(10)
    print("hermite(10) nodes=", nodes, "and weights=", weights)
except:
    import sys
    print("t_HermiteFactory_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    # Instanciate one distribution object
    distribution = KPermutationsDistribution(5, 12)
    print("Distribution ", distribution)

    # Is this distribution elliptical ?
    print("Elliptical = ", distribution.isElliptical())

    # Is this distribution continuous ?
    print("Continuous = ", distribution.isContinuous())

    # Test for realization of distribution
    oneRealization = distribution.getRealization()
    print("oneRealization=", oneRealization)

    # Test for sampling
    size = 10000
    oneSample = distribution.getSample(size)
    print("oneSample first=", oneSample[0], " last=", oneSample[size - 1])
    print("mean=", oneSample.computeMean())
    print("covariance=", oneSample.computeCovariance())
    # Define a point
    point = Point(distribution.getDimension(), 4.0)
    print("Point= ", point)

    # Show PDF and CDF of point
    LPDF = distribution.computeLogPDF(point)
    print("log pdf=", LPDF)
    PDF = distribution.computePDF(point)
    print("pdf     =", PDF)
    CDF = distribution.computeCDF(point)
    print("cdf=%.6f" % CDF)
    CCDF = distribution.computeComplementaryCDF(point)
    print("ccdf=%.6f" % CCDF)
    quantile = distribution.computeQuantile(0.95)
    print("quantile=", quantile)
    print("cdf(quantile)=", distribution.computeCDF(quantile))
    print("entropy=%.6f" % distribution.computeEntropy())
    mean = distribution.getMean()
    print("mean=", mean)
    covariance = distribution.getCovariance()
    print("covariance=", covariance)
    parameters = distribution.getParametersCollection()
    print("parameters=", parameters)

except:
    import sys
    print("t_KPermutationsDistribution_std.py",
          sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

ot.TESTPREAMBLE()

regularGrid = ot.RegularGrid(-1.0, 0.1, 21)
regularGridNearestNeighbourAlgorithm = ot.RegularGridNearestNeighbour(
    regularGrid)
print('regularGridNearestNeighbourAlgorithm=',
      regularGridNearestNeighbourAlgorithm)

test = ot.Normal().getSample(20)
for i in range(len(test)):
    index = regularGridNearestNeighbourAlgorithm.query(test[i])
    neighbour = ot.Point(1, regularGrid.getValue(
        regularGridNearestNeighbourAlgorithm.query(test[i])))
    print('Nearest neighbour of', test[i], '=', neighbour, 'index=', index)

k = 4
for i in range(len(test)):
    indices = regularGridNearestNeighbourAlgorithm.queryK(test[i], k, True)
    print(k, 'nearest neighbours of', test[i], '(indices=', indices)



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:

    continuousDistributionCollection = DistributionCollection()
    discreteDistributionCollection = DistributionCollection()
    distributionCollection = DistributionCollection()

    beta = Beta(2., 1., 0., 1.)
    distributionCollection.add(beta)
    continuousDistributionCollection.add(beta)

    gamma = Gamma(1., 2., 3.)
    distributionCollection.add(gamma)
    continuousDistributionCollection.add(gamma)

    gumbel = Gumbel(1., 2.)
    distributionCollection.add(gumbel)
    continuousDistributionCollection.add(gumbel)

    lognormal = LogNormal(1., 1., 2.)
    distributionCollection.add(lognormal)
    continuousDistributionCollection.add(lognormal)

    logistic = Logistic(1., 1.)
    distributionCollection.add(logistic)
    continuousDistributionCollection.add(logistic)

    normal = Normal(1., 2.)
    distributionCollection.add(normal)
    continuousDistributionCollection.add(normal)

    truncatednormal = TruncatedNormal(1., 1., 0., 3.)
    distributionCollection.add(truncatednormal)
    continuousDistributionCollection.add(truncatednormal)

    student = Student(10., 10.)
    distributionCollection.add(student)
    continuousDistributionCollection.add(student)

    triangular = Triangular(-1., 2., 4.)
    distributionCollection.add(triangular)
    continuousDistributionCollection.add(triangular)

    uniform = Uniform(1., 2.)
    distributionCollection.add(uniform)
    continuousDistributionCollection.add(uniform)

    weibull = WeibullMin(1., 1., 2.)
    distributionCollection.add(weibull)
    continuousDistributionCollection.add(weibull)

    geometric = Geometric(.5)
    distributionCollection.add(geometric)
    discreteDistributionCollection.add(geometric)

    poisson = Poisson(2.)
    distributionCollection.add(poisson)
    discreteDistributionCollection.add(poisson)

    x = [[1.0], [2.0], [3.0]]
    p = [0.3, 0.2, 0.5]
    userdefined = UserDefined(x, p)
    distributionCollection.add(userdefined)
    discreteDistributionCollection.add(userdefined)

    size = 10000

    # Number of continuous distributions
    continuousDistributionNumber = continuousDistributionCollection.getSize()
    # Number of discrete distributions
    discreteDistributionNumber = discreteDistributionCollection.getSize()
    # Number of distributions
    distributionNumber = continuousDistributionNumber + \
        discreteDistributionNumber

    # We create a collection of Sample of size "size" and of
    # dimension 1 (scalar values) : the collection has distributionNumber
    # Samples
    sampleCollection = [Sample(size, 1)
                        for i in range(distributionNumber)]
    # We create a collection of Sample of size "size" and of
    # dimension 1 (scalar values) : the collection has
    # continuousDistributionNumber Samples
    continuousSampleCollection = [Sample(size, 1)
                                  for i in range(continuousDistributionNumber)]
    # We create a collection of Sample of size "size" and of
    # dimension 1 (scalar values) : the collection has
    # discreteDistributionNumber Samples
    discreteSampleCollection = [Sample(size, 1)
                                for i in range(discreteDistributionNumber)]

    for i in range(continuousDistributionNumber):
        continuousSampleCollection[
            i] = continuousDistributionCollection[i].getSample(size)
        continuousSampleCollection[i].setName(
            continuousDistributionCollection[i].getName())
        sampleCollection[i] = continuousSampleCollection[i]
    for i in range(discreteDistributionNumber):
        discreteSampleCollection[
            i] = discreteDistributionCollection[i].getSample(size)
        discreteSampleCollection[i].setName(
            discreteDistributionCollection[i].getName())
        sampleCollection[
            continuousDistributionNumber + i] = discreteSampleCollection[i]

    # Test the normality of several samples using the Anderson Darling test
    andersonDarlingResult = Point(distributionNumber)
    for i in range(distributionNumber):
        result = NormalityTest.AndersonDarlingNormal(sampleCollection[i])
        andersonDarlingResult[i] = result.getBinaryQualityMeasure()
        print("sample ", sampleCollection[
              i].getName(), " result=", andersonDarlingResult[i])
    print("andersonDarlingResult=", repr(andersonDarlingResult))

    # Test the normality of several samples using the Cramer Von Mises test
    cramerVonMisesResult = Point(distributionNumber)
    for i in range(distributionNumber):
        result = NormalityTest.CramerVonMisesNormal(sampleCollection[i])
        cramerVonMisesResult[i] = result.getBinaryQualityMeasure()
        print("sample ", sampleCollection[
              i].getName(), " result=", cramerVonMisesResult[i])
    print("cramerVonMisesResult=", repr(cramerVonMisesResult))

except:
    import sys
    print("t_NormalityTest_std.py", sys.exc_info()[0], sys.exc_info()[1])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import print_function
import openturns as ot
import openturns.testing as ott


def printResults(result, problemName):
    print("*** {} completed:".format(problemName))
    print("      -- Optimal point = ", result.getOptimalPoint())
    print("      -- Optimal value = ", result.getOptimalValue())
    print("      -- Iteration number = ", result.getIterationNumber())
    print("      -- Evaluation number = ", result.getEvaluationNumber())
    print("      -- Absolute error = {:.6e}".format(result.getAbsoluteError()))
    print("      -- Relative error = {:.6e}".format(result.getRelativeError()))
    print("      -- Residual error = {:.6e}".format(result.getResidualError()))
    print(
        "      -- Constraint error = {:.6e}".format(result.getConstraintError()))


# Define the problems based on Rastrigin function
rastrigin = ot.SymbolicFunction(
    ['x1', 'x2'], ['20 + x1^2 - 10*cos(2*pi_*x1) + x2^2 - 10*cos(2*pi_*x2)'])

unboundedProblem = ot.OptimizationProblem(rastrigin)

notConstrainingBounds = ot.Interval([-5.0, -5.0], [3.0, 2.0])
notConstrainingBoundsProblem = ot.OptimizationProblem(
    rastrigin, ot.Function(), ot.Function(), notConstrainingBounds)

constrainingBounds = ot.Interval([-1.0, -2.0], [5.0, -0.5])
constrainingBoundsProblem = ot.OptimizationProblem(
    rastrigin, ot.Function(), ot.Function(), constrainingBounds)

boundedPref = [0.0, -1.0]
unboundedPref = [0.0, 0.0]

## GLOBAL ALGORITHM ##

# Non-contraining bounds Global
notConstrainingBoundsGlobal = ot.Dlib(notConstrainingBoundsProblem, "Global")
notConstrainingBoundsGlobal.setStartingPoint([0.0]*2)
notConstrainingBoundsGlobal.setMaximumEvaluationNumber(300)
notConstrainingBoundsGlobal.run()
printResults(notConstrainingBoundsGlobal.getResult(),
             "Non-constraining bounds Global")

# Contraining bounds Global
constrainingBoundsGlobal = ot.Dlib(constrainingBoundsProblem, "Global")
constrainingBoundsGlobal.setMaximumEvaluationNumber(300)
constrainingBoundsGlobal.setStartingPoint([0.0]*2)
constrainingBoundsGlobal.run()
printResults(constrainingBoundsGlobal.getResult(),
             "Constraining bounds Global")

ott.assert_almost_equal(notConstrainingBoundsGlobal.getResult(
).getOptimalPoint(), unboundedPref, 1, 1e-4)
ott.assert_almost_equal(
    constrainingBoundsGlobal.getResult().getOptimalPoint(), boundedPref, 1, 1e-4)



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

generators = [
    ot.Tuples([4, 6, 9]), ot.KPermutations(4, 6), ot.Combinations(4, 6)]

for generator in generators:
    print ('generator:', generator)
    subsets = generator.generate()
    print ('subset:', subsets)



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

mesh = ot.RegularGrid(0.0, 0.1, 11)


class FUNC(ot.OpenTURNSPythonFieldToPointFunction):

    def __init__(self):
        # first argument:
        super(FUNC, self).__init__(mesh, 2, 2)
        self.setInputDescription(['R', 'S'])
        self.setOutputDescription(['T', 'U'])

    def _exec(self, X):
        Y = ot.Sample(X).computeMean()
        return Y


F = FUNC()
print('in_dim=' + str(F.getInputDimension())
      + ' out_dim=' + str(F.getOutputDimension())
      + ' spatial_dim=' + str(F.getInputMesh().getDimension()))

X = ot.Field(mesh, ot.Normal(2).getSample(11))
print(F(X.getValues()))

Xsample = ot.ProcessSample(5, X)
print(F(Xsample))

# Instance creation
myFunc = ot.FieldToPointFunction(F)

# Copy constructor
newFunc = ot.FieldToPointFunction(myFunc)

print('myFunc input dimension= ' + str(myFunc.getInputDimension()))
print('myFunc output dimension= ' + str(myFunc.getOutputDimension()))

print(myFunc(X.getValues()))

print(myFunc(Xsample))


vertices = []
vertices.append([0.0, 0.0, 0.0])
vertices.append([0.0, 0.0, 1.0])
vertices.append([0.0, 1.0, 0.0])
vertices.append([0.0, 1.0, 1.0])
vertices.append([1.0, 0.0, 0.0])
vertices.append([1.0, 0.0, 1.0])
vertices.append([1.0, 1.0, 0.0])
vertices.append([1.0, 1.0, 1.0])
simplicies = []
simplicies.append([0, 1, 2, 4])
simplicies.append([3, 5, 6, 7])
simplicies.append([1, 2, 3, 6])
simplicies.append([1, 2, 4, 6])
simplicies.append([1, 3, 5, 6])
simplicies.append([1, 4, 5, 6])
mesh3D = ot.Mesh(vertices, simplicies)


def myPyFunc(X):
    Y = ot.Sample(X).computeMean()
    return Y


in_dim = 3
out_dim = 3

myFunc = ot.PythonFieldToPointFunction(mesh3D, in_dim, out_dim, myPyFunc)
print('myFunc=', myFunc)


values = ot.Normal(mesh3D.getDimension()).getSample(mesh3D.getVerticesNumber())
# Evaluation over a single field
X = ot.Field(mesh3D, values)
print('X=', X)
Y = myFunc(X.getValues())
print('Y=', Y)
print('myFunc input dimension=', myFunc.getInputDimension())
print('myFunc output dimension=', myFunc.getOutputDimension())
print('myFunc input dimension=', myFunc.getInputMesh().getDimension())
print('called ', myFunc.getCallsNumber(), ' times')
# Evaluation over a process sample
X = ot.ProcessSample(5, X)
print('X=', X)
Y = myFunc(X)
print('Y=', Y)
print('myFunc input dimension=', myFunc.getInputDimension())
print('myFunc output dimension=', myFunc.getOutputDimension())
print('myFunc input dimension=', myFunc.getInputMesh().getDimension())
print('called ', myFunc.getCallsNumber(), ' times')



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

ot.TESTPREAMBLE()


def test_active_parameter():
    # Define product of matern 1d
    cov_model_1d = ot.MaternModel([0.5], 2.5)
    print("1D Full parameter : ", cov_model_1d.getFullParameter())
    print("1D active cov. param.: ", [cov_model_1d.getFullParameterDescription()[
          i] for i in cov_model_1d.getActiveParameter()])
    print("Activate nu parameter")
    cov_model_1d.setActiveParameter([0, 1, 2])
    print("active cov. param.: ", [cov_model_1d.getFullParameterDescription()[
          i] for i in cov_model_1d.getActiveParameter()])

    print("Matern d-dimensional covariance as product")
    d = 3
    cov_model = ot.ProductCovarianceModel([cov_model_1d]*d)
    print("Full parameter : ", cov_model.getFullParameter())
    print("active cov. param.: ", [cov_model.getFullParameterDescription()[
          i] for i in cov_model.getActiveParameter()])
    print("Disable nu for marginals 0 & 1 parameter : ",
          cov_model.getFullParameter())
    cov_model.setActiveParameter([0, 1, 2, 3, 6])
    print("active cov. param.: ", [cov_model.getFullParameterDescription()[
          i] for i in cov_model.getActiveParameter()])
    print("Check that active parameter is correctly propagated")

    for k in range(3):
        print("Model ", k, " : active cov. param.: ", [cov_model.getCollection()[
              k].getFullParameterDescription()[i] for i in cov_model.getCollection()[k].getActiveParameter()])


def test_active_amplitude_parameter():
    # Define product of matern 1d
    model1 = ot.MaternModel([1.0], 2.5)
    print("Model 1 : ", model1.getFullParameterDescription())
    print("Activate nu parameter and disable sigma2")
    model1.setActiveParameter([0, 2])
    print("model1 active parameter: ", [model1.getFullParameterDescription()[
          i] for i in model1.getActiveParameter()])

    model2 = ot.ExponentiallyDampedCosineModel()
    print("Model 2 : ", model2.getFullParameterDescription())
    print("Activate freq parameter")
    model2.setActiveParameter([0, 1, 2])
    print("model2 active parameter: ", [model2.getFullParameterDescription()[
          i] for i in model2.getActiveParameter()])

    print("Product covariance model")
    d = 3
    cov_model = ot.ProductCovarianceModel([model1, model2])
    print("Full parameter : ", cov_model.getFullParameter())
    print("active cov. param.: ", [cov_model.getFullParameterDescription()[
          i] for i in cov_model.getActiveParameter()])


test_active_parameter()
test_active_amplitude_parameter()



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

ot.TESTPREAMBLE()
ot.RandomGenerator.SetSeed(0)


mu = [0.0] * 4
sigma = [1.0] * 4
a = [-4., -1., 1., 3.]
b = [4., 4., 2., 6.]

for i in range(4):
    ot.PlatformInfo.SetNumericalPrecision(1 if i == 2 else 2)
    distribution = ot.TruncatedNormal(mu[i], sigma[i], a[i], b[i])
    size = 10000
    sample = distribution.getSample(size)
    factory = ot.TruncatedNormalFactory()
    estimatedDistribution = factory.build(sample)
    print("distribution=", repr(distribution))
    print("Estimated distribution=", repr(estimatedDistribution))
    estimatedDistribution = factory.build()
    print("Default distribution=", estimatedDistribution)
    estimatedDistribution = factory.build(
        distribution.getParameter())
    print("Distribution from parameters=", estimatedDistribution)
    estimatedTruncatedNormal = factory.buildAsTruncatedNormal(sample)
    print("TruncatedNormal          =", distribution)
    print("Estimated TruncatedNormal=", estimatedTruncatedNormal)
    estimatedTruncatedNormal = factory.buildAsTruncatedNormal()
    print("Default TruncatedNormal=", estimatedTruncatedNormal)
    estimatedTruncatedNormal = factory.buildAsTruncatedNormal(
        distribution.getParameter())
    print("TruncatedNormal from parameters=", estimatedTruncatedNormal)
sample = [[0.0]] * size
estimatedDistribution = factory.build(sample)
print("Estimated distribution=", repr(estimatedDistribution))
sample = [[1.0]] * size
estimatedDistribution = factory.build(sample)
print("Estimated distribution=", repr(estimatedDistribution))



#! /usr/bin/env python

from __future__ import print_function
from openturns import *
from math import *

TESTPREAMBLE()

try:

    # DEFAULT CONSTRUCTOR AND STRING CONVERTER
    print("test 0 : default constructor and string converter")

    # Default constructor
    matrix0 = ComplexMatrix()

    # String converter
    print("matrix0 = ", repr(matrix0))

    # CONSTRUCTOR WITH SIZE, OPERATOR() AND STRING CONVERTER
    print(
        "test number one : constructor with size, operator() and string converter")

    # Constructor with size
    matrix1 = ComplexMatrix(2, 2)

    # Check operator() methods
    matrix1[0, 0] = 1. + 1j
    matrix1[1, 0] = 2. + 4j
    matrix1[0, 1] = 3. - 1j
    matrix1[1, 1] = 4.

    # String converter
    print("matrix1 = ", repr(matrix1))

    # COPY CONSTRUCTOR AND STRING CONVERTER
    print("test 2 : copy constructor and string converter")

    # Copy constructor
    matrix2 = ComplexMatrix(matrix1)

    # String converter
    print("matrix2 = ", repr(matrix2))

    # GET DIMENSIONS METHODS
    print("test 3 : dimension methods")

    # Get dimension methods
    print("matrix1's nbRows = ", matrix1.getNbRows())
    print("matrix1's nbColumns = ", matrix1.getNbColumns())

    # CONSTRUCTOR WITH COLLECTION
    print("test 4 : constructor with collection method")

    # Create the collection of values
    elementsValues = ComplexCollection()
    elementsValues.add(1. - 1j)
    elementsValues.add(2. - 1j)
    elementsValues.add(3. - 1j)
    elementsValues.add(4. + 1j)
    elementsValues.add(5. + 1j)
    elementsValues.add(6. + 1j)

    # Check the content of the collection
    print("elementsValues = ", repr(elementsValues))

    # Check the constructor with collection
    matrix0bis = ComplexMatrix(2, 2, elementsValues)
    print("matrix0bis = ", repr(matrix0bis))

    # TRANSPOSITION METHOD AND CONJUGATE METHOD
    print("test 5 : transposition / conjugate method")

    # Check transpose method
    matrix4 = matrix1.transpose()
    matrix5 = matrix1.conjugate()
    print("matrix1 transposed = ", repr(matrix4))
    print("matrix1 conjugated = ", repr(matrix5))

    # TRANSPOSITION AND CONJUGATE COUPLED METHOD
    print("transposition and conjugate method")

    # Check transpose method
    matrix6 = matrix1.conjugateTranspose()
    print("matrix1 conjugated and transposed = ", repr(matrix6))

    # ADDITION METHOD
    print("test 6 : addition method")

    # Check addition method : we check the operator and the symmetry of the
    # operator, thus testing the comparison operator
    sum1 = matrix1 + matrix4
    sum2 = matrix4 + matrix1
    print("sum1 = ", repr(sum1))
    print("sum2 = ", repr(sum2))
    print("sum1 equals sum2 = ", sum1 == sum2)

    # SUBTRACTION METHOD
    print("test 7 : subtraction method")

    # Check subtraction method
    diff = matrix1 - matrix4
    print("diff = ", repr(diff))

    #  MATRIX MULTIPLICATION METHOD
    print("test 8 : matrix multiplication method")

    # Check multiplication method
    prod = matrix1 * matrix4
    print("prod = ", repr(prod))

    # MULTIPLICATION WITH A NUMERICAL POINT METHOD
    print("test 9 : multiplication with a numerical point method")

    # Create the numerical point
    pt = Point()
    pt.add(1.)
    pt.add(2.)
    print("pt = ", repr(pt))

    # Check the product method
    ptResult = matrix1 * pt
    print("ptResult = ", repr(ptResult))

    #  MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS
    print(
        "test 10 : multiplication and division by a numerical scalar methods")

    # Check the multiplication method
    s = 3. + 1j
    scalprod1 = matrix1 * s
    print("scalprod1 = ", repr(scalprod1))

    # Check the division method
    scaldiv1 = matrix1 / s
    print("scaldiv1 = ", repr(scaldiv1))

    #  ISEMPTY METHOD
    print("test 10 : isEmpty method")

    # Check method isEmpty
    matrix7 = ComplexMatrix()
    matrix8 = ComplexMatrix()

    print("matrix1 is empty = ", matrix1.isEmpty())
    print("matrix5 is empty = ", matrix7.isEmpty())
    print("matrix6 is empty = ", matrix8.isEmpty())
    print("matrix0 is empty = ", matrix0.isEmpty())

    # MULTIPLICATION WITH A NUMERICAL POINT METHOD
    print("test 11 : multiplication with a numerical point method")

    # Create the numerical point
    pt_test = Point()
    pt_test.add(1.)
    pt_test.add(2.)
    print("pt_test = ", repr(pt_test))

    A = ComplexMatrix(2, 2)
    A[0, 0] = 0.5
    A[1, 0] = -(sqrt(3.) / 2)
    A[0, 1] = (sqrt(3.) / 2)
    A[1, 1] = 0.5
    B = A.transpose()
    identity = B * A

    # Check the product method
    ptResult2 = identity * pt_test
    print("A = ", repr(A))
    print("B = ", repr(B))
    print("identity = ", repr(identity))
    print("ptResult2 = ", repr(ptResult2))
except:
    import sys
    print("t_ComplexMatrix_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

try:
    # Construction based on two functions
    # Create an instance
    grid = RegularGrid(0.0, 0.1, 11)
    myFunc = FieldToFieldConnection(
        ValueFunction(SymbolicFunction("x", "sin(x)"), grid), ValueFunction(SymbolicFunction("x", "cos(x)"), grid))

    print("myFunc=", myFunc)
    # Get the input and output description
    print("myFunc input description=", myFunc.getInputDescription())
    print("myFunc output description=", myFunc.getOutputDescription())
    # Get the input and output dimension
    print("myFunc input dimension=", myFunc.getInputDimension())
    print("myFunc output dimension=", myFunc.getOutputDimension())
    # Connection on a point
    field = Field(grid, grid.getVertices() * [2.0])
    print("field=", field)
    print("myFunc(field)=", myFunc(field))
    # Get the number of calls
    print("called ", myFunc.getCallsNumber(), " times")

    # Construction based on a FieldToPointFunction followed by a PointToFieldFunction
    # Create a KarhunenLoeveResult
    mesh = IntervalMesher([9]).build(Interval(-1.0, 1.0))
    cov1D = AbsoluteExponential([1.0])
    algo = KarhunenLoeveP1Algorithm(mesh, cov1D, 0.0)
    algo.run()
    result = algo.getResult()
    # Create a PointToFieldFunction
    lifting = KarhunenLoeveLifting(result)
    # Create a FieldToPointFunction
    projection = KarhunenLoeveProjection(result)
    # Create an instance
    myFunc = FieldToFieldConnection(lifting, projection)

    print("myFunc=", myFunc)
    # Get the input and output description
    print("myFunc input description=", myFunc.getInputDescription())
    print("myFunc output description=", myFunc.getOutputDescription())
    # Get the input and output dimension
    print("myFunc input dimension=", myFunc.getInputDimension())
    print("myFunc output dimension=", myFunc.getOutputDimension())
    # Connection on a point
    field = result.getModesAsProcessSample().computeMean()
    print("field=", field)
    print("myFunc(field)=", myFunc(field))
    # Get the number of calls
    print("called ", myFunc.getCallsNumber(), " times")

except:
    import sys
    print("t_FieldToFieldConnection_std.py",
          sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *
from openturns.testing import *

TESTPREAMBLE()

# Test 1

sampleSize = 6
dimension = 1

f = SymbolicFunction(['x0'], ['x0 * sin(x0)'])

X = Sample(sampleSize, dimension)
X2 = Sample(sampleSize, dimension)
for i in range(sampleSize):
    X[i, 0] = 3.0 + i
    X2[i, 0] = 2.5 + i
X[0, 0] = 1.0
X[1, 0] = 3.0
X2[0, 0] = 2.0
X2[1, 0] = 4.0
Y = f(X)
Y2 = f(X2)

# create algorithm
basis = ConstantBasisFactory(dimension).build()
covarianceModel = SquaredExponential([1e-05], [4.11749])

algo = KrigingAlgorithm(X, Y, covarianceModel, basis)
algo.run()

# perform an evaluation
result = algo.getResult()
print("X=", X)
print("f(X)=", Y)

assert_almost_equal(result.getMetaModel()(X), Y)
assert_almost_equal(result.getResiduals(), [1.32804e-07], 1e-3, 1e-3)
assert_almost_equal(result.getRelativeErrors(), [5.20873e-21])

# Kriging variance is 0 on learning points
covariance = result.getConditionalCovariance(X)

# assert_almost_equal could not be applied to matrices
# application to Point
covariancePoint = Point(covariance.getImplementation())
theoricalVariance = Point(sampleSize * sampleSize)
assert_almost_equal(covariancePoint, theoricalVariance, 8.95e-7, 8.95e-7)

# Covariance per marginal & extract variance component
coll = result.getConditionalMarginalCovariance(X)
var = [mat[0, 0] for mat in coll]
covarianceColl = Point(var)
theoricalVariance = Point(sampleSize)
assert_almost_equal(covarianceColl, theoricalVariance, 1e-14, 1e-14)

# Variance per marginal
var = result.getConditionalMarginalVariance(X)
assert_almost_equal(var, Point(sampleSize), 1e-14, 1e-14)

# Test 2

# Kriging use case
inputDimension = 2

# Learning data
levels = [8, 5]
box = Box(levels)
inputSample = box.generate()
# Scale each direction
inputSample *= 10.0


model = SymbolicFunction(['x', 'y'], ['cos(0.5*x) + sin(y)'])
outputSample = model(inputSample)

# Validation
sampleSize = 10
inputValidSample = ComposedDistribution(
    2 * [Uniform(0, 10.0)]).getSample(sampleSize)
outputValidSample = model(inputValidSample)

# 2) Definition of exponential model
# The parameters have been calibrated using TNC optimization
# and AbsoluteExponential models
covarianceModel = SquaredExponential([1.98824, 0.924731], [3.15352])

# 3) Basis definition
basisCollection = BasisCollection(
    1, ConstantBasisFactory(inputDimension).build())

# Kriring algorithm
algo = KrigingAlgorithm(inputSample, outputSample,
                        covarianceModel, basisCollection)
algo.run()
result = algo.getResult()
# Get meta model
metaModel = result.getMetaModel()
outData = metaModel(inputValidSample)


# 4) Errors
# Interpolation
assert_almost_equal(outputSample,  metaModel(inputSample), 3.0e-5, 3.0e-5)


# 5) Kriging variance is 0 on learning points
covariance = result.getConditionalCovariance(inputSample)

# assert_almost_equal could not be applied to matrices
# application to Point
covariancePoint = Point(covariance.getImplementation())
theoricalVariance = Point(covariancePoint.getSize(), 0.0)
assert_almost_equal(covariancePoint, theoricalVariance, 7e-7, 7e-7)

# Covariance per marginal & extract variance component
coll = result.getConditionalMarginalCovariance(inputSample)
var = [mat[0, 0] for mat in coll]
covarianceColl = Point(var)
theoricalVariance = Point(len(var))
assert_almost_equal(covarianceColl, theoricalVariance, 1e-14, 1e-14)

# Variance per marginal
var = result.getConditionalMarginalVariance(inputSample)
assert_almost_equal(var, Point(len(inputSample)), 1e-14, 1e-14)

# Estimation
assert_almost_equal(outputValidSample,  metaModel(
    inputValidSample), 1.e-1, 1e-1)



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    distribution = Normal(4)
    size = 10
    weightingDistribution = Normal(distribution)
    weightingDistribution.setMean(Point(4, 1.0))
    experiment = ImportanceSamplingExperiment(
        distribution, weightingDistribution, size)
    print("experiment = ", experiment)
    sample, weights = experiment.generateWithWeights()
    print("sample = ", repr(sample))
    print("weights = ", repr(weights))
except:
    import sys
    print("t_ImportanceSamplingExperiment_std.py",
          sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

dim = 10
R = CorrelationMatrix(dim)
for i in range(dim):
    for j in range(i):
        R[i, j] = (i + j + 1.0) / (2.0 * dim)
mean = Point(dim, 2.0)
sigma = Point(dim, 3.0)
distribution = Normal(mean, sigma, R)

size = 100
sample = distribution.getSample(size)
sampleX = Sample(size, dim - 1)
sampleY = Sample(size, 1)
for i in range(size):
    sampleY[i, 0] = sample[i, 0]
    for j in range(1, dim):
        sampleX[i, j - 1] = sample[i, j]

sampleZ = Sample(size, 1)
for i in range(size):
    sampleZ[i, 0] = sampleY[i, 0] * sampleY[i, 0]

selection = Indices(5)
selection.fill()
print('selection = ', selection)

# PartialPearson : Independence Pearson test between 2 samples : firstSample of dimension n and secondSample of dimension 1. If firstSample[i] is the numerical sample extracted from firstSample (ith coordinate of each point of the numerical sample), PartialPearson performs the Independence Pearson test simultaneously on firstSample[i] and secondSample, for i in the selection. For all i, it is supposed that the couple (firstSample[i] and secondSample) is issued from a gaussian  vector.
# Probability of the H0 reject zone : 0.10

print('PartialPearsonXY=', HypothesisTest.PartialPearson(
    sampleX, sampleY, selection, 0.10))

selection2 = Indices(1, 0)
sampleX0 = Sample(size, 1)
for i in range(size):
    sampleX0[i, 0] = sampleX[i, 0]

# The three tests must be equal
print('PartialPearsonX0Y=', HypothesisTest.PartialPearson(
    sampleX, sampleY, selection2, 0.10))
print('PearsonX0Y=', HypothesisTest.Pearson(sampleX0, sampleY, 0.10))
print('FullPearsonX0Y=', HypothesisTest.FullPearson(
    sampleX0, sampleY, 0.10))

# FullPearson : Independence Pearson test between 2 samples : firstSample of dimension n and secondSample of dimension 1. If firstSample[i] is the numerical sample extracted from firstSample (ith coordinate of each point of the numerical sample), FullPearson performs the Independence Pearson test simultaneously on firstSample[i] and secondSample. For all i, it is supposed that the couple (firstSample[i] and secondSample) is issued from a gaussian  vector.
# Probability of the H0 reject zone : 0.10
print('FullPearsonXY=', HypothesisTest.FullPearson(
    sampleX, sampleY, 0.10))
print('FullPearsonYY=', HypothesisTest.FullPearson(
    sampleY, sampleY, 0.10))



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    dimension = 2
    epsilon = Point(dimension, 1e-4)
    x = Point(dimension, 2.0)

    step = ConstantStep(epsilon)
    print('step type=', step.getClassName(), 'step value=', step(x))

    eta = Point(dimension, 1.0)
    step = BlendedStep(epsilon, eta)
    print('step type=', step.getClassName(), 'step value=', step(x))

except:
    import sys
    print("t_FiniteDifferenceStep_std.py",
          sys.exc_info()[0], sys.exc_info()[1])
